@@ -166,7 +166,7 @@ int get_mmc_profile (int fd)
   unsigned char buf[8],inq[128];
   unsigned char *sense=cmd.sense();
   int i;
-  int profile=0,once=1,blank=0,err,erasable=0;
+  int profile=0,once=1,blank=0,err;
   unsigned int len;
 
   /* For valgrind */
@@ -200,13 +200,12 @@ int get_mmc_profile (int fd)
     cmd[9] = 0;
     if ((err=cmd.transport(READ,buf,sizeof(buf)))) {
       /*sperror ("GET CONFIGURATION",err);*/
-      /* this is not a fatal error -- some older drives support MMC-1
-       * but don't support the GET CONFIGURATION command (which is part
-       * of the MMC-2 spec). */
-    } else {
-        if ((profile = buf[6]<<8|buf[7]) || !once) break;
+      fprintf (stderr, "Could not determine drive profile: non-MMC unit?\n");
+      goto bail;
     }
 
+    if ((profile = buf[6]<<8|buf[7]) || !once) break;
+
     // no media?
     cmd[0] = 0;	// TEST UNIT READY
     cmd[5] = 0;
@@ -237,24 +236,6 @@ int get_mmc_profile (int fd)
   // see if it's blank media
   if ((disc_info[2]&3) == 0)	blank=0x10000;
 
-  if (!profile ) {
-      /* if the profile has not yet been set, we're dealing with an older
-       * CD-R or CD-RW burner (which doesn't know the GET CONFIGURATION
-       * command.  Do some digging into the disc type to figure out what's
-       * in the drive */
-      erasable = ((disc_info[2] & 16));
-      if (blank && !erasable) {
-          profile = 0x09;  /* CD-R                        */
-      } else if (erasable) {
-          profile = 0x0a;  /* CD-RW                       */
-      } else if (disc_info[8] == 0x00) {
-          profile = 0x08;  /* Commercial CDs and Audio CD */
-      } else {
-         fprintf (stderr, "Could not determine profile or type of media\n");
-         goto bail;
-      }
-  }
-
   if (profile != 0x1A && profile != 0x13 && profile != 0x12)
     return blank|profile;
 
@@ -388,13 +369,13 @@ bail:
   return retval;
 }
 
-extern "C"
-gint64 get_disc_size_cd (int fd)
+static gint64
+get_read_capacity (Scsi_Command &cmd)
 {
-  Scsi_Command cmd (fd);
   unsigned char data [8];
-  unsigned int ccity, bsize;
-  int retval = -1;
+  gint64 ccity;
+  gint64 bsize;
+  gint64 retval = -1;
   int len;
 
   /* For valgrind */
@@ -411,13 +392,21 @@ gint64 get_disc_size_cd (int fd)
   ccity++;
   bsize = data [4] << 24 | data [5] << 16 | data [6] << 8 | data [7];
 
-  return ccity * bsize;
+  retval = ccity * bsize;
 
 bail:
 
   return retval;
 }
 
+extern "C"
+gint64 get_disc_size_cd (int fd)
+{
+  Scsi_Command cmd (fd);
+
+  return get_read_capacity (cmd);
+}
+
 static unsigned int get_2k_capacity (Scsi_Command &cmd, int mmc_profile)
 { unsigned char	buf[32];
   unsigned int	ret=0;
@@ -532,12 +521,22 @@ retry:
   return ret;
 }
 
-/* Returns the size of a DVD+R[W] or DVD-R[W] in bytes */
+/* Returns the size of a DVD in bytes */
 extern "C"
-gint64 get_disc_size_dvd (int fd, int mmc_profile)
+gint64 get_disc_size_dvd (int fd)
 {
   Scsi_Command cmd(fd);
-  return (gint64)get_2k_capacity(cmd, mmc_profile)*2048;
+
+  return get_read_capacity (cmd);
+}
+
+/* Returns the size of a DVD+R[W] or DVD-R[W] in bytes */
+extern "C"
+gint64 get_disc_size_dvdr (int fd, int mmc_profile)
+{
+  Scsi_Command cmd(fd);
+
+  return (gint64)get_2k_capacity(cmd, mmc_profile) * 2048;
 }
 
 extern "C"
