@@ -34,8 +34,11 @@ list_drives (void)
 
 	for (l = drives; l != NULL; l = l->next) {
 		char       *type_str;
+		char       *display_name;
 		const char *media;
 		int         media_type;
+		int         max_speed_read;
+		int         max_speed_write;
 		gboolean    is_rewritable;
 		gboolean    is_blank;
 		gboolean    has_data;
@@ -53,11 +56,15 @@ list_drives (void)
 		media = nautilus_burn_drive_media_type_get_string (media_type);
 
 		door_is_open = nautilus_burn_drive_door_is_open (drive);
+		display_name = nautilus_burn_drive_get_name_for_display (drive);
+		max_speed_read = nautilus_burn_drive_get_max_speed_read (drive);
+		max_speed_write = nautilus_burn_drive_get_max_speed_read (drive);
 
 		g_print ("name: %s device: %s max_speed_read: %d\n",
-			 drive->display_name,
+			 display_name,
 			 drive->device,
-			 drive->max_speed_read);
+			 max_speed_read);
+
 		g_print ("door: %s\n", door_is_open ? "open" : "closed");
 		g_print ("type: %s\n", type_str);
 		g_print ("media type: %s%s%s%s%s\n",
@@ -84,12 +91,13 @@ list_drives (void)
 			g_print ("media size: Could not be determined\n");
 		}
 
-		g_print ("CD-Recorder/SCSI devices only: max_speed_write: %d"
-			 " id: %s\n", drive->max_speed_write,
-			 drive->cdrecord_id);
+		g_print ("CD-Recorder/SCSI devices only: max_speed_write: %d\n", max_speed_write);
+
 		g_print ("\n");
 
+		g_free (display_name);
 		g_free (type_str);
+
 		nautilus_burn_drive_unref (drive);
 	}
 
