@@ -56,7 +56,7 @@ int      nautilus_burn_make_iso            (const char                  *filenam
 					    NautilusBurnImageType       *type,
 					    GError                     **error);
 int      nautilus_burn_make_iso_from_drive (const char                  *filename,
-					    const NautilusBurnDrive     *drive,
+					    NautilusBurnDrive           *drive,
 					    NautilusBurnImageCreateFlags flags,
 					    NautilusBurnImageType       *type,
 					    char                       **toc_filename,
