@@ -391,7 +391,6 @@ nautilus_burn_drive_selection_set_recorders_only (NautilusBurnDriveSelection *se
 	selection->priv->show_recorders_only = recorders_only;
 }
 
-/* Properties */
 static void
 nautilus_burn_drive_selection_set_property (GObject      *object,
 					    guint         property_id,
@@ -448,12 +447,101 @@ nautilus_burn_drive_selection_get_property (GObject    *object,
 	}
 }
 
+/**
+ * nautilus_burn_drive_selection_set_active:
+ * @selection: #NautilusBurnDriveSelection
+ * @drive: #NautilusBurnDrive
+ *
+ * Set the current selected drive to that which corresponds to the
+ * specified drive.
+ *
+ * Since: 2.14
+ *
+ **/
+void
+nautilus_burn_drive_selection_set_active (NautilusBurnDriveSelection *selection,
+					  NautilusBurnDrive          *drive)
+{
+	GList             *l;
+	gboolean           found;
+	int                i;
+
+	g_return_if_fail (selection != NULL);
+	g_return_if_fail (NAUTILUS_BURN_IS_DRIVE_SELECTION (selection));
+
+	found = FALSE;
+	i = -1;
+	for (l = selection->priv->cdroms; l != NULL && found == FALSE; l = l->next) {
+		NautilusBurnDrive *drive2;
+
+		i++;
+
+		drive2 = l->data;
+
+		if (nautilus_burn_drive_equal (drive, drive2)) {
+			found = TRUE;
+		}
+	}
+
+	if (found) {
+		gtk_combo_box_set_active (GTK_COMBO_BOX (selection), i);
+	} else {
+		/* If the device doesn't exist, set it back to
+		 * the default */
+		gtk_combo_box_set_active (GTK_COMBO_BOX (selection), 0);
+
+		drive = get_drive (selection, 0);
+
+		if (drive == NULL)
+			return;
+
+		g_signal_emit (G_OBJECT (selection),
+			       nautilus_burn_drive_selection_table_signals [DEVICE_CHANGED],
+			       0, drive->device);
+	}
+}
+
+/**
+ * nautilus_burn_drive_selection_get_active:
+ * @selection: #NautilusBurnDriveSelection
+ *
+ * Get the currently selected drive
+ *
+ * Return value: currently selected #NautilusBurnDrive.  The drive must be
+ * unreffed using nautilus_burn_drive_unref after use.
+ *
+ * Since: 2.14
+ *
+ **/
+NautilusBurnDrive *
+nautilus_burn_drive_selection_get_active (NautilusBurnDriveSelection *selection)
+{
+	NautilusBurnDrive *drive;
+	int                i;
+
+	g_return_val_if_fail (selection != NULL, NULL);
+	g_return_val_if_fail (NAUTILUS_BURN_IS_DRIVE_SELECTION (selection), NULL);
+
+	i = gtk_combo_box_get_active (GTK_COMBO_BOX (selection));
+	drive = get_drive (selection, i);
+
+	if (drive)
+		nautilus_burn_drive_ref (drive);
+
+	return drive;
+}
+
+
+/* Deprecated functions */
+
 /**
  * nautilus_burn_drive_selection_get_default_device:
  * @selection: #NautilusBurnDriveSelection
  *
  * Get the block device name that corresponds to the default drive.
  *
+ * Deprecated:
+ *
  **/
 const char *
 nautilus_burn_drive_selection_get_default_device (NautilusBurnDriveSelection *selection)
@@ -481,6 +569,8 @@ nautilus_burn_drive_selection_get_default_device (NautilusBurnDriveSelection *se
  * Set the current selected drive to that which corresponds to the
  * specified block device name.
  *
+ * Deprecated: Use nautilus_burn_drive_selection_set_active() instead
+ *
  **/
 void
 nautilus_burn_drive_selection_set_device (NautilusBurnDriveSelection *selection,
@@ -533,6 +623,9 @@ nautilus_burn_drive_selection_set_device (NautilusBurnDriveSelection *selection,
  *
  * Return value: String block device name that corresponds to the
  * currently selected drive
+ *
+ * Deprecated: Use nautilus_burn_drive_selection_get_active() instead
+ *
  **/
 const char *
 nautilus_burn_drive_selection_get_device (NautilusBurnDriveSelection *selection)
@@ -556,6 +649,9 @@ nautilus_burn_drive_selection_get_device (NautilusBurnDriveSelection *selection)
  * Get the currently selected drive
  *
  * Return value: currently selected #NautilusBurnDrive
+ *
+ * Deprecated: Use nautilus_burn_drive_selection_get_active() instead
+ *
  **/
 const NautilusBurnDrive *
 nautilus_burn_drive_selection_get_drive (NautilusBurnDriveSelection *selection)
