@@ -886,9 +886,7 @@ nautilus_burn_recorder_write_tracks (NautilusBurnRecorder          *recorder,
 	recorder->priv->track_count = g_list_length (tracks);
 	recorder->priv->debug = (flags & NAUTILUS_BURN_RECORDER_WRITE_DEBUG);
 
-	/* Let's hope that DVD+RW and DVD-RW drives can also do CD-RWs */
-	recorder->priv->can_rewrite =
-		(drive->type & NAUTILUS_BURN_DRIVE_TYPE_CDRW_RECORDER);
+	recorder->priv->can_rewrite = nautilus_burn_drive_can_rewrite (drive);
 
 	if (recorder->priv->track_count > 99) {
 		g_set_error (error,
@@ -1368,6 +1366,7 @@ nautilus_burn_recorder_write_growisofs (NautilusBurnRecorder          *recorder,
 	g_free (speed_str);
 	g_free (dev_str);
 	g_ptr_array_free (argv, TRUE);
+	argv = NULL;
 	
 	g_signal_emit (recorder,
 		       nautilus_burn_recorder_table_signals [ANIMATION_CHANGED], 0,
@@ -1600,6 +1599,7 @@ nautilus_burn_recorder_write_cdrecord (NautilusBurnRecorder          *recorder,
 	g_free (speed_str);
 	g_free (dev_str);
 	g_ptr_array_free (argv, TRUE);
+	argv = NULL;
 
 	return result;
 }
